/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2010 University of Bonn. All rights reserved.
 * Please see the LICENSE file or "Copyright notice" in builder.cpp for details.
 */

/*
 * ConnectedSubgraph.cpp
 *
 *  Created on: Feb 16, 2011
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include <iostream>

#include "ConnectedSubgraph.hpp"

#include "atom.hpp"
#include "CodePatterns/Assert.hpp"
#include "CodePatterns/Log.hpp"
#include "CodePatterns/Verbose.hpp"
#include "molecule.hpp"
#include "World.hpp"

ConnectedSubgraph::ConnectedSubgraph()
{}

ConnectedSubgraph::~ConnectedSubgraph()
{}

molecule * ConnectedSubgraph::getMolecule() const
{
  molecule *mol = World::getInstance().createMolecule();
  mol->ActiveFlag = true;
  // TODO: Remove the insertion into molecule when saving does not depend on them anymore. Also, remove molecule.hpp include
  World::getInstance().getMolecules()->insert(mol);

  ASSERT(!empty(),
      "ConnectedSubgraph::getMolecule() - we contain no atoms.");
  for (AtomList::const_iterator iter = begin();
      iter != end();
      ++iter) {
#ifndef NDEBUG
    bool status =
#endif
        mol->AddAtom(*iter);
    ASSERT(status,
        "ConnectedSubgraph::getMolecule() - could not add "
        +toString(*this)+" to molecule "+toString(mol)+".");
  }

  return mol;
}

std::ostream & operator<<(std::ostream &ost, const ConnectedSubgraph &graph)
{
  for (ConnectedSubgraph::const_iterator iter = graph.begin();
      iter != graph.end();
      ++iter) {
    if (iter != graph.begin())
      ost << ", ";
    ost << (*iter)->getName();
  }
  return ost;
}
